automake-patches
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

FYI: typos


From: Ralf Wildenhues
Subject: FYI: typos
Date: Fri, 20 Oct 2006 19:18:53 +0200
User-agent: Mutt/1.5.13 (2006-09-08)

Applied to branch-1-10 and HEAD.

Cheers,
Ralf

2006-10-20  Ralf Wildenhues  <address@hidden>

        * doc/automake.texi (Dist, Dependency Tracking Evolution):
        Fix some typos.
        * lib/Automake/Condition.pm: Likewise.
        * lib/Automake/DisjConditions.pm: Likewise.
        * lib/Automake/ItemDef.pm: Likewise.
        * lib/Automake/Options.pm: Likewise.
        * lib/Automake/Rule.pm: Likewise.
        * lib/Automake/VarDef.pm: Likewise.
        * lib/Automake/Variable.pm: Likewise.
        * lib/Automake/Wrap.pm: Likewise.
        * lib/Automake/XFile.pm: Likewise.
        * m4/substnot.m4: Likewise.

Index: doc/automake.texi
===================================================================
RCS file: /cvs/automake/automake/doc/automake.texi,v
retrieving revision 1.159
diff -u -r1.159 automake.texi
--- doc/automake.texi   16 Oct 2006 05:24:17 -0000      1.159
+++ doc/automake.texi   20 Oct 2006 16:36:45 -0000
@@ -7944,7 +7944,7 @@
         cp -p $(srcdir)/random/a1 $(srcdir)/random/a2 $(distdir)/random
 @end example
 
-Another way to to use this is for removing unnecessary files that get
+Another way to use this is for removing unnecessary files that get
 recursively included by specifying a directory in EXTRA_DIST:
 
 @example
@@ -11799,9 +11799,8 @@
 
 The current fix is to use @code{BUILT_SOURCES} to list built headers
 (@pxref{Sources}).  This causes them to be built before any other
-other build rules are run.  This is unsatisfactory as a general
-solution, however in practice it seems sufficient for most actual
-programs.
+build rules are run.  This is unsatisfactory as a general solution,
+however in practice it seems sufficient for most actual programs.
 @end itemize
 
 This code is used since Automake 1.5.
Index: lib/Automake/Condition.pm
===================================================================
RCS file: /cvs/automake/automake/lib/Automake/Condition.pm,v
retrieving revision 1.6
diff -u -r1.6 Condition.pm
--- lib/Automake/Condition.pm   13 May 2006 09:28:36 -0000      1.6
+++ lib/Automake/Condition.pm   20 Oct 2006 16:36:45 -0000
@@ -144,13 +144,13 @@
 the form C<"NAME_FALSE"> or C<"NAME_TRUE"> where C<NAME> can be
 anything (in practice C<NAME> should be the name of a conditional
 declared in F<configure.ac> with C<AM_CONDITIONAL>, but it's not
-C<Automake::Condition>'s responsability to ensure this).
+C<Automake::Condition>'s responsibility to ensure this).
 
 An empty C<@conds> means C<"TRUE">.
 
 As explained previously, the reference (object) returned is unique
 with respect to C<@conds>.  For this purpose, duplicate elements are
-ignored, and C<@conds> is rewriten as C<("FALSE")> if it contains
+ignored, and C<@conds> is rewritten as C<("FALSE")> if it contains
 C<"FALSE"> or two contradictory conditionals (such as C<"NAME_FALSE">
 and C<"NAME_TRUE">.)
 
Index: lib/Automake/DisjConditions.pm
===================================================================
RCS file: /cvs/automake/automake/lib/Automake/DisjConditions.pm,v
retrieving revision 1.14
diff -u -r1.14 DisjConditions.pm
--- lib/Automake/DisjConditions.pm      13 May 2006 09:28:36 -0000      1.14
+++ lib/Automake/DisjConditions.pm      20 Oct 2006 16:36:45 -0000
@@ -46,7 +46,7 @@
   my $cond = $set->one_cond;
 
   # Return true iff $set is always true (i.e. its subconditions
-  # conver all cases).
+  # cover all cases).
   if ($set->true) { ... }
 
   # Return false iff $set is always false (i.e. is empty, or contains
@@ -331,7 +331,7 @@
 
 =cut
 
-# Same as multiply() but take a list of Conditonals as second argument.
+# Same as multiply() but take a list of Conditionals as second argument.
 # We use this in invert().
 sub _multiply ($@)
 {
Index: lib/Automake/ItemDef.pm
===================================================================
RCS file: /cvs/automake/automake/lib/Automake/ItemDef.pm,v
retrieving revision 1.2
diff -u -r1.2 ItemDef.pm
--- lib/Automake/ItemDef.pm     14 May 2005 20:28:51 -0000      1.2
+++ lib/Automake/ItemDef.pm     20 Oct 2006 16:36:45 -0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2003  Free Software Foundation, Inc.
+# Copyright (C) 2003, 2006  Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
 Automake reorders items in the output, it also tries to carry comments
 around.)
 
-C<$location> is the place where the definition occured, it should be
+C<$location> is the place where the definition occurred, it should be
 an instance of L<Automake::Location>.
 
 C<$owner> specifies who owns the rule.
Index: lib/Automake/Options.pm
===================================================================
RCS file: /cvs/automake/automake/lib/Automake/Options.pm,v
retrieving revision 1.6
diff -u -r1.6 Options.pm
--- lib/Automake/Options.pm     13 May 2006 09:28:36 -0000      1.6
+++ lib/Automake/Options.pm     20 Oct 2006 16:36:45 -0000
@@ -104,11 +104,11 @@
 
 =item C<$strictness>
 
-The current stricness.  One of C<FOREIGN>, C<GNU>, or C<GNITS>.
+The current strictness.  One of C<FOREIGN>, C<GNU>, or C<GNITS>.
 
 =item C<$strictness_name>
 
-The current stricness name.  One of C<'foreign'>, C<'gnu'>, or C<'gnits'>.
+The current strictness name.  One of C<'foreign'>, C<'gnu'>, or C<'gnits'>.
 
 =back
 
@@ -239,7 +239,7 @@
 # -------------------------------------------------
 # Process a list of options.  Return 1 on error, 0 otherwise.
 # \%OPTIONS is the hash to fill with options data, $WHERE is
-# the location where @OPTIONS occured.
+# the location where @OPTIONS occurred.
 sub _process_option_list (\%$@)
 {
   my ($options, $where, @list) = @_;
Index: lib/Automake/Rule.pm
===================================================================
RCS file: /cvs/automake/automake/lib/Automake/Rule.pm,v
retrieving revision 1.11
diff -u -r1.11 Rule.pm
--- lib/Automake/Rule.pm        28 Aug 2006 16:04:24 -0000      1.11
+++ lib/Automake/Rule.pm        20 Oct 2006 16:36:45 -0000
@@ -143,7 +143,7 @@
 transforming C<.foo> to C<.$(OBJEXT)> involves a chain of several
 suffix rules.
 
-The value of C<$suffix_rules{$ext1}{$ext2}> is the a pair
+The value of C<$suffix_rules{$ext1}{$ext2}> is a pair
 C<[ $next_sfx, $dist ]> where C<$next_sfx> is target suffix
 for the next rule to use to reach C<$ext2>, and C<$dist> the
 distance to C<$ext2'>.
@@ -555,7 +555,7 @@
 }
 
 
-=itcem C<@conds = define ($rulename, $source, $owner, $cond, $where)>
+=item C<@conds = define ($rulename, $source, $owner, $cond, $where)>
 
 Define a new rule.  C<$rulename> is the list of targets.  C<$source>
 is the filename the rule comes from.  C<$owner> is the owner of the
@@ -644,7 +644,7 @@
                }
              # Return so we don't redefine the rule in our tables,
              # don't check for ambiguous condition, etc.  The rule
-             # will be output anyway beauce &read_am_file ignore the
+             # will be output anyway because &read_am_file ignore the
              # return code.
              return ();
            }
@@ -689,7 +689,7 @@
              # Automake should ignore redefinitions of its own
              # rules if they came from the same file.  This makes
              # it easier to process a Makefile fragment several times.
-             # Hower it's an error if the target is defined in many
+             # However it's an error if the target is defined in many
              # files.  E.g., the user might be using bin_PROGRAMS = ctags
              # which clashes with our `ctags' rule.
              # (It would be more accurate if we had a way to compare
@@ -780,7 +780,7 @@
       # Check if the rule is a suffix rule: either it's a rule for
       # two known extensions...
       if ($t =~ /^($KNOWN_EXTENSIONS_PATTERN)($KNOWN_EXTENSIONS_PATTERN)$/
-         # ...or it's a rule with unknown extensions (.i.e, the rule
+         # ...or it's a rule with unknown extensions (i.e., the rule
          # looks like `.foo.bar:' but `.foo' or `.bar' are not
          # declared in SUFFIXES and are not known language
          # extensions).  Automake will complete SUFFIXES from
Index: lib/Automake/VarDef.pm
===================================================================
RCS file: /cvs/automake/automake/lib/Automake/VarDef.pm,v
retrieving revision 1.8
diff -u -r1.8 VarDef.pm
--- lib/Automake/VarDef.pm      13 May 2006 09:28:36 -0000      1.8
+++ lib/Automake/VarDef.pm      20 Oct 2006 16:36:45 -0000
@@ -100,7 +100,7 @@
 C<VAR_PRETTY> variables.
 
 C<VAR_SILENT> variables can also be overridden silently (unlike the
-other kinds of variables whose overridding may sometimes produce
+other kinds of variables whose overriding may sometimes produce
 warnings).
 
 =cut
@@ -130,7 +130,7 @@
 Automake reorders variable definitions in the output, it also tries to
 carry comments around.)
 
-C<$location> is the place where the definition occured, it should be
+C<$location> is the place where the definition occurred, it should be
 an instance of L<Automake::Location>.
 
 C<$type> should be C<''> for definitions made with C<=>, and C<':'>
@@ -167,7 +167,7 @@
 
 =item C<$def-E<gt>append ($value, $comment)>
 
-Append C<$value> and <$comment> to the exisiting value and comment of
+Append C<$value> and <$comment> to the existing value and comment of
 C<$def>.  This is normally called on C<+=> definitions.
 
 =cut
Index: lib/Automake/Wrap.pm
===================================================================
RCS file: /cvs/automake/automake/lib/Automake/Wrap.pm,v
retrieving revision 1.3
diff -u -r1.3 Wrap.pm
--- lib/Automake/Wrap.pm        13 May 2006 09:28:36 -0000      1.3
+++ lib/Automake/Wrap.pm        20 Oct 2006 16:36:46 -0000
@@ -68,7 +68,7 @@
 C<"$eol\n$fill"> so that the length of each line never exceeds
 C<$max_len>.
 
-The C<$max_len> contraint is ignored for C<@values> items which
+The C<$max_len> constraint is ignored for C<@values> items which
 are too big to fit alone one a line.
 
 The constructed paragraph is C<"\n">-terminated.
Index: lib/Automake/XFile.pm
===================================================================
RCS file: /cvs/automake/automake/lib/Automake/XFile.pm,v
retrieving revision 1.11
diff -u -r1.11 XFile.pm
--- lib/Automake/XFile.pm       25 May 2006 10:21:47 -0000      1.11
+++ lib/Automake/XFile.pm       20 Oct 2006 16:36:46 -0000
@@ -66,7 +66,7 @@
 C<Automake::XFile> inherits from C<IO::File>.  It provides the method
 C<name> returning the file name.  It provides dying version of the
 methods C<close>, C<lock> (corresponding to C<flock>), C<new>,
-C<open>, C<seek>, and C<trunctate>.  It also overrides the C<getline>
+C<open>, C<seek>, and C<truncate>.  It also overrides the C<getline>
 and C<getlines> methods to translate C<\r\n> to C<\n>.
 
 =head1 SEE ALSO
Index: m4/substnot.m4
===================================================================
RCS file: /cvs/automake/automake/m4/substnot.m4,v
retrieving revision 1.1
diff -u -r1.1 substnot.m4
--- m4/substnot.m4      9 Apr 2006 07:46:55 -0000       1.1
+++ m4/substnot.m4      20 Oct 2006 16:36:46 -0000
@@ -7,6 +7,6 @@
 
 # _AM_SUBST_NOTMAKE(VARIABLE)
 # ---------------------------
-# Prevent Automake from outputing VARIABLE = @VARIABLE@ in Makefile.in.
+# Prevent Automake from outputting VARIABLE = @VARIABLE@ in Makefile.in.
 # This macro is traced by Automake.
 AC_DEFUN([_AM_SUBST_NOTMAKE])




reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: lib/Automake/Variable.pm
===================================================================
RCS file: /cvs/automake/automake/lib/Automake/Variable.pm,v
retrieving revision 1.46
diff -u -r1.46 Variable.pm
--- lib/Automake/Variable.pm    14 Oct 2006 09:33:34 -0000      1.46
+++ lib/Automake/Variable.pm    20 Oct 2006 16:36:46 -0000
@@ -193,7 +193,7 @@
 # The name of the configure.ac file.
 my $configure_ac = find_configure_ac;
 
 # Variables that can be overriden without complaint from -Woverride
 my %_silent_variable_override =
   (AM_MAKEINFOHTMLFLAGS => 1,
    AR => 1,
@@ -743,7 +743,7 @@
   while ($text =~ /(?<!\$)\$(?:\{([^\}]*)\}|\(([^\)]*)\))/g)
     {
       my $var = $1 || $2;
-      # The occurence may look like $(string1[:subst1=[subst2]]) but
+      # The occurrence may look like $(string1[:subst1=[subst2]]) but
       # we want only `string1'.
       $var =~ s/:[^:=]*=[^=]*$//;
       push @result, $var;
@@ -789,7 +789,7 @@
 
 C<$owner>: owner of the variable (one of C<VAR_MAKEFILE>,
 C<VAR_CONFIGURE>, or C<VAR_AUTOMAKE>, defined by L<Automake::VarDef>).
-Variables can be overriden, provided the new owner is not weaker
+Variables can be overridden, provided the new owner is not weaker
 (C<VAR_AUTOMAKE> < C<VAR_CONFIGURE> < C<VAR_MAKEFILE>).
 
 C<$type>: the type of the assignment (C<''> for C<FOO = bar>,
@@ -1263,12 +1263,12 @@
                    traversing
    $val,        -- the item (i.e., filename) to process
    $cond,       -- the Condition for the $var definition we are
-                   examinating (ignoring the recursion context)
+                   examining (ignoring the recursion context)
    $full_cond)  -- the full Condition, taking into account
                    conditions inherited from parent variables
                    during recursion
 
-If C<inner_expand> is set, variable references occuring in filename
+If C<inner_expand> is set, variable references occurring in filename
 (as in C<$(BASE).ext>) are expansed before the filename is passed to
 C<&fun_item>.
 
@@ -1489,7 +1489,7 @@
 
 # _hash_values (@VALUES)
 # ----------------------
-# Hash @VALUES for %_gen_varname.  @VALUES shoud be a list
+# Hash @VALUES for %_gen_varname.  @VALUES should be a list
 # of pairs: ([$cond, @values], [$cond, @values], ...).
 # See _gen_varname() below.
 sub _hash_values (@)
@@ -193,7 +193,7 @@
 my $configure_ac = find_configure_ac;
 
-# Variables that can be overriden without complaint from -Woverride
+# Variables that can be overridden without complaint from -Woverride
 my %_silent_variable_override =
   (AM_MAKEINFOHTMLFLAGS => 1,